==> 4.2.0.tar.gz: lib/src/presentation/screens/enrollment_form/enrollment_form_screen.dart <==
import 'package:dcoupon_sdk_flutter_package/src/domain/entities/enrollment_form.dart';
import 'package:dcoupon_sdk_flutter_package/src/presentation/screens/enrollment_form/widgets/legal_doc_list_item_widget.dart';
import 'package:dcoupon_sdk_flutter_package/src/presentation/widgets/dialogs.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/translations.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';

class EnrollmentFormScreen extends StatefulWidget {
  final EnrollmentForm enrollmentForm;
  final VoidCallback onCloseEnrollment;
  final VoidCallback onAcceptEnrollment;

  EnrollmentFormScreen({
    Key? key,
    required this.enrollmentForm,
    required this.onCloseEnrollment,
    required this.onAcceptEnrollment,
  }) : super(key: key);

  @override
  _EnrollmentFormScreenState createState() => _EnrollmentFormScreenState();
}

class _EnrollmentFormScreenState extends State<EnrollmentFormScreen> {
  bool? _checkboxIsSelected = false;
  var _isLoading = false;
  late bool _hasPreviousAgreements;

  List<dynamic> legalDocumentsToAccept = <dynamic>[];

  @override
  void initState() {
    super.initState();
    _hasPreviousAgreements = widget.enrollmentForm.legalDocumentsList
        .any((element) => element.versionChangesTextMap.isNotEmpty);
  }

  void closeEnrollment() {
    widget.onCloseEnrollment();
  }

  void acceptEnrollment() {
    setState(() {
      _isLoading = true;
    });

    widget.onAcceptEnrollment();
  }

  @override
  Widget build(BuildContext context) {
    final importantStyle = TextStyle(fontWeight: FontWeight.bold);
    return Scaffold(
      appBar: AppBar(
        centerTitle: true,
        elevation: 0,
        bottom: PreferredSize(
          child: Container(
            color: Theme.of(context).textTheme.bodyText2!.color,
            height: 0.2,
          ),
          preferredSize: Size.fromHeight(0.2),
        ),
        title: new Image(
          fit: BoxFit.scaleDown,
          height: 40,
          image: new AssetImage(
            'lib/assets/images/dcoupon_logo.png',
            package: 'dcoupon_sdk_flutter_package',
          ),
        ),
        leading: BackButton(
          onPressed: () {
            closeEnrollment();
          },
        ),
      ),
      backgroundColor: Theme.of(context).colorScheme.background,
      body: Builder(
        builder: (context) => Stack(
          children: [
            NotificationListener<OverscrollIndicatorNotification>(
              onNotification: (OverscrollIndicatorNotification overscroll) {
                overscroll.disallowGlow();
                return false;
              },
              child: ListView(
                padding: EdgeInsets.all(32.0),
                children: <Widget>[
                  _hasPreviousAgreements
                      ? Text(Translations.of(context)!
                          .text('dcoupon_updated_documents'))
                      : Text(Translations.of(context)!
                          .text('dcoupon_mandatory_documents')),
                  SizedBox(
                    height: 32,
                  ),
                  ListView.separated(
                    physics: NeverScrollableScrollPhysics(),
                    shrinkWrap: true,
                    itemCount: widget.enrollmentForm.legalDocumentsList.length,
                    itemBuilder: (BuildContext context, int index) {
                      final legalDocument =
                          widget.enrollmentForm.legalDocumentsList[index];
                      return LegalDocListItemWidget(
                        legalDocument: legalDocument,
                        onTap: () {
                          MyDialogs.showHtmlDialog(
                            context,
                            data: legalDocument.contentText,
                          );
                        },
                      );
                    },
                    separatorBuilder: (BuildContext context, int index) {
                      return SizedBox(
                        height: 16,
                      );
                    },
                  ),
                  SizedBox(
                    height: 24,
                  ),
                  Row(
                    children: <Widget>[
                      Checkbox(
                        value: _checkboxIsSelected,
                        onChanged: (bool? value) {
                          setState(() {
                            _checkboxIsSelected = value;
                          });
                        },
                      ),
                      SizedBox(width: 8),
                      Flexible(
                        child: RichText(
                          text: TextSpan(
                            style: Theme.of(context)
                                .textTheme
                                .bodyText2!
                                .copyWith(fontSize: 13),
                            children: <TextSpan>[
                              TextSpan(
                                text: Translations.of(context)!
                                        .text('dcoupon_agreeTo') +
                                    ' ',
                              ),
                              ...List<TextSpan>.generate(
                                widget.enrollmentForm.legalDocumentsList.length,
                                (int index) {
                                  final legalDocument = widget
                                      .enrollmentForm.legalDocumentsList[index];
                                  String separator = '';
                                  if (index != 0) {
                                    separator = ', ';
                                  }
                                  if (widget.enrollmentForm.legalDocumentsList
                                              .length >
                                          1 &&
                                      index ==
                                          widget.enrollmentForm
                                                  .legalDocumentsList.length -
                                              1) {
                                    separator = ' ' +
                                        Translations.of(context)!
                                            .text('dcoupon_and') +
                                        ' ';
                                  }
                                  return TextSpan(
                                    text: separator +
                                        Translations.of(context)!.text(
                                            'dcoupon_legal_${legalDocument.type}'),
                                    style: importantStyle,
                                    recognizer: TapGestureRecognizer()
                                      ..onTap = () {
                                        MyDialogs.showHtmlDialog(
                                          context,
                                          data: legalDocument.contentText,
                                        );
                                      },
                                  );
                                },
                              ),
                            ],
                          ),
                        ),
                      ),
                    ],
                  ),
                  SizedBox(
                    height: 8,
                  ),
                  ElevatedButton(
                    style: ElevatedButton.styleFrom(
                      shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(6.0),
                      ),
                    ),
                    child: Text(
                        Translations.of(context)!.text('dcoupon_continue')),
                    onPressed: _checkboxIsSelected!
                        ? () {
                            acceptEnrollment();
                          }
                        : null,
                  ),
                ],
              ),
            ),
            Container(
              child: _isLoading
                  ? Container(
                      color: Colors.grey[200]!.withAlpha(150),
                      height: MediaQuery.of(context).size.height,
                      child: Center(
                        child: CircularProgressIndicator(),
                      ),
                    )
                  : Container(),
            ),
          ],
        ),
      ),
    );
  }
}

==> 4.4.0.tar.gz: lib/src/presentation/screens/enrollment_form/enrollment_form_screen.dart <==
import 'package:dcoupon_sdk_flutter_package/src/domain/entities/enrollment_form.dart';
import 'package:dcoupon_sdk_flutter_package/src/presentation/screens/enrollment_form/widgets/legal_doc_list_item_widget.dart';
import 'package:dcoupon_sdk_flutter_package/src/presentation/widgets/dialogs.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/translations.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';

class EnrollmentFormScreen extends StatefulWidget {
  final EnrollmentForm enrollmentForm;
  final VoidCallback onCloseEnrollment;
  final VoidCallback onAcceptEnrollment;

  EnrollmentFormScreen({
    Key? key,
    required this.enrollmentForm,
    required this.onCloseEnrollment,
    required this.onAcceptEnrollment,
  }) : super(key: key);

  @override
  _EnrollmentFormScreenState createState() => _EnrollmentFormScreenState();
}

class _EnrollmentFormScreenState extends State<EnrollmentFormScreen> {
  bool? _checkboxIsSelected = false;
  var _isLoading = false;
  late bool _hasPreviousAgreements;

  List<dynamic> legalDocumentsToAccept = <dynamic>[];

  @override
  void initState() {
    super.initState();
    _hasPreviousAgreements = widget.enrollmentForm.legalDocumentsList
        .any((element) => element.versionChangesTextMap.isNotEmpty);
  }

  void closeEnrollment() {
    widget.onCloseEnrollment();
  }

  void acceptEnrollment() {
    setState(() {
      _isLoading = true;
    });

    widget.onAcceptEnrollment();
  }

  @override
  Widget build(BuildContext context) {
    final importantStyle = TextStyle(fontWeight: FontWeight.bold);
    return Scaffold(
      appBar: AppBar(
        centerTitle: true,
        elevation: 0,
        bottom: PreferredSize(
          child: Container(
            color: Theme.of(context).textTheme.bodyText2!.color,
            height: 0.2,
          ),
          preferredSize: Size.fromHeight(0.2),
        ),
        title: new Image(
          fit: BoxFit.scaleDown,
          height: 40,
          image: new AssetImage(
            'lib/assets/images/dcoupon_logo.png',
            package: 'dcoupon_sdk_flutter_package',
          ),
        ),
        leading: BackButton(
          onPressed: () {
            closeEnrollment();
          },
        ),
      ),
      backgroundColor: Theme.of(context).colorScheme.background,
      body: Builder(
        builder: (context) => Stack(
          children: [
            NotificationListener<OverscrollIndicatorNotification>(
              onNotification: (OverscrollIndicatorNotification overscroll) {
                overscroll.disallowIndicator();
                return false;
              },
              child: ListView(
                padding: EdgeInsets.all(32.0),
                children: <Widget>[
                  _hasPreviousAgreements
                      ? Text(Translations.of(context)!
                          .text('dcoupon_updated_documents'))
                      : Text(Translations.of(context)!
                          .text('dcoupon_mandatory_documents')),
                  SizedBox(
                    height: 32,
                  ),
                  ListView.separated(
                    physics: NeverScrollableScrollPhysics(),
                    shrinkWrap: true,
                    itemCount: widget.enrollmentForm.legalDocumentsList.length,
                    itemBuilder: (BuildContext context, int index) {
                      final legalDocument =
                          widget.enrollmentForm.legalDocumentsList[index];
                      return LegalDocListItemWidget(
                        legalDocument: legalDocument,
                        onTap: () {
                          MyDialogs.showWebviewDialog(
                            context,
                            url: legalDocument.contentUrl,
                          );
                        },
                      );
                    },
                    separatorBuilder: (BuildContext context, int index) {
                      return SizedBox(
                        height: 16,
                      );
                    },
                  ),
                  SizedBox(
                    height: 24,
                  ),
                  Row(
                    children: <Widget>[
                      Checkbox(
                        value: _checkboxIsSelected,
                        onChanged: (bool? value) {
                          setState(() {
                            _checkboxIsSelected = value;
                          });
                        },
                      ),
                      SizedBox(width: 8),
                      Flexible(
                        child: RichText(
                          text: TextSpan(
                            style: Theme.of(context)
                                .textTheme
                                .bodyText2!
                                .copyWith(fontSize: 13),
                            children: <TextSpan>[
                              TextSpan(
                                text: Translations.of(context)!
                                        .text('dcoupon_agreeTo') +
                                    ' ',
                              ),
                              ...List<TextSpan>.generate(
                                widget.enrollmentForm.legalDocumentsList.length,
                                (int index) {
                                  final legalDocument = widget
                                      .enrollmentForm.legalDocumentsList[index];
                                  String separator = '';
                                  if (index != 0) {
                                    separator = ', ';
                                  }
                                  if (widget.enrollmentForm.legalDocumentsList
                                              .length >
                                          1 &&
                                      index ==
                                          widget.enrollmentForm
                                                  .legalDocumentsList.length -
                                              1) {
                                    separator = ' ' +
                                        Translations.of(context)!
                                            .text('dcoupon_and') +
                                        ' ';
                                  }
                                  return TextSpan(
                                    text: separator +
                                        Translations.of(context)!.text(
                                            'dcoupon_legal_${legalDocument.type}'),
                                    style: importantStyle,
                                    recognizer: TapGestureRecognizer()
                                      ..onTap = () {
                                        MyDialogs.showWebviewDialog(
                                          context,
                                          url: legalDocument.contentUrl,
                                        );
                                      },
                                  );
                                },
                              ),
                            ],
                          ),
                        ),
                      ),
                    ],
                  ),
                  SizedBox(
                    height: 8,
                  ),
                  ElevatedButton(
                    style: ElevatedButton.styleFrom(
                      shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(6.0),
                      ),
                    ),
                    child: Text(
                        Translations.of(context)!.text('dcoupon_continue')),
                    onPressed: _checkboxIsSelected!
                        ? () {
                            acceptEnrollment();
                          }
                        : null,
                  ),
                ],
              ),
            ),
            Container(
              child: _isLoading
                  ? Container(
                      color: Colors.grey[200]!.withAlpha(150),
                      height: MediaQuery.of(context).size.height,
                      child: Center(
                        child: CircularProgressIndicator(),
                      ),
                    )
                  : Container(),
            ),
          ],
        ),
      ),
    );
  }
}
